@@ -684,13 +684,13 @@ if True:
         if hasattr(print, "indent"):
             if print.indent.size > 0:
                 indent = print.indent.string*print.indent.size
-                # starting indent depending on previous ending
-                if len(prev_end) > 0 and prev_end[-1] in ('\n', '\r'):
-                    output_str += indent
                 # dump to string
                 output_str = print(*args, **{ **kwargs, "to_string":True})
                 # indent any contained newlines 
                 output_str = output_str.replace("\n", "\n"+indent)[0:-len(indent)]
+                # starting indent depending on previous ending
+                if len(prev_end) > 0 and prev_end[-1] in ('\n', '\r'):
+                    output_str = indent + output_str
                 # print it
                 return real_print(output_str, **{ "flush": print.flush.always, **kwargs, "end":""}) 
         
